@@ -5,7 +5,8 @@ push @ARGV, "";
 if($ARGV[0] eq "--help")
 {
 print STDERR <<EOT;
-usage:	bdftopsf [+u|-u] [+o|-o OUTPUT] [--] [INPUT [TABLE...]]
+usage:	bdftopsf [+h][+u|-u][+1|-1]|[-h[+r|-r]] [+o|-o OUTPUT]
+	[--] [INPUT [TABLE...]]
 
 +h	PSF mode - write a PSF header. This is the default.
   +u	Write an unicode table. Default for fonts with more
@@ -14,7 +15,6 @@ usage:	bdftopsf [+u|-u] [+o|-o OUTPUT] [--] [INPUT [TABLE...]]
 	or less characters.
   +1	Use PSF1. Default for fonts with 256 or 512 characters,
         width 8 and height less than 256.
-	256 and characters
   -1    Use PSF2. Default for all other fonts.
 
 -h	RAW mode - write no PSF header (and no unicode table,
@@ -52,7 +52,7 @@ EOT
 if($ARGV[0] eq "--version")
 {
 print STDERR <<EOT;
-bdftopsf.pl 0.1.0, Copyright (C) 2003 Dimitar Zhekov
+bdftopsf.pl 0.1.2, Copyright (C) 2004 Dimitar Zhekov
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -135,6 +135,7 @@ elsif($ARGV[0] eq "-o")
 }
 
 if($ARGV[0] eq "--") { shift @ARGV; }
+elsif($ARGV[0] =~ /^([-+][0-9a-z])$/) { print STDERR "$0: suspicuous $1, use -- to terminate the option list\n"; }
 pop @ARGV;
 
 if($#ARGV < 0) { $ARGV[0] = "-"; }
@@ -231,9 +232,10 @@ if($#ARGV > 0)
 			{
 				next if /^\s*$/;
 				/^([0-9a-fA-F]{1,4})\s+([0-9a-fA-F]{1,4})$/ || die("$0: $ARGV[0]: invalid unicode(s) $_\n");
-				hex($1) != hex($2) || die("$0: $ARGV[0]: invalid duplicate entry $_\n");
-				foreach(@{$unidup{hex($1)}}) { if($_ == hex($2)) { $2 = "65535"; last; } }
-				if(hex($2) != 65535) { push @{$unidup{hex($1)}}, hex($2); }
+				$duplicate = hex($2);
+				hex($1) != $duplicate || die("$0: $ARGV[0]: invalid duplicate entry $_\n");
+				foreach(@{$unidup{hex($1)}}) { if($_ == $duplicate) { $duplicate = 65535; last; } }
+				if($duplicate != 65535) { push @{$unidup{hex($1)}}, $duplicate; }
 			}
 			close DUP;
 		} while($#ARGV > 0);
